@@ -15,7 +15,8 @@ from lia.check_git.verify_branch import verify_branch
 @click.group()
 def spells() -> None:
     """
-    Collection for Lia's spells/methods.
+    Collection for Lia's spells. For more info ask for help
+    on each specific spell.
     """
     pass  # pragma: no cover
 
@@ -25,7 +26,9 @@ def spells() -> None:
 @click.option("-t", default="y", help="If test should be run")
 def heal(packagename: str, t: str) -> None:  # pragma: no cover
     """
-    One of Lias most basic spells.
+    One of Lias most basic spells. It lints, and typechecks
+    the code specified in the path. To test use the -t option.
+    Lia only supports pytest.
 
     The heal function is a wrapper for the following commands:
         - black
@@ -69,7 +72,12 @@ def heal(packagename: str, t: str) -> None:  # pragma: no cover
         shell=True,
         check=True,
     )
-    subprocess.run([f"mypy --strict {packagename}"], shell=True, check=True)
+    try:
+        subprocess.run(
+            [f"mypy --strict {packagename}"], shell=True, check=True)
+    except Exception as exc:
+        print(str(exc))
+
     try:
         subprocess.run(
             [f"python -m pylint -f parseable {packagename}"], shell=True, check=True
@@ -79,7 +87,10 @@ def heal(packagename: str, t: str) -> None:  # pragma: no cover
     subprocess.run(
         [f"prettify-py format-dir {packagename}"], shell=True, check=True)
     if t == "y":
-        subprocess.run(["python -m pytest tests/"], shell=True, check=True)
+        try:
+            subprocess.run(["python -m pytest tests/"], shell=True, check=True)
+        except Exception as exc:
+            print(str(exc))
     say_end_message()
 
 
@@ -97,7 +108,7 @@ def deploy(t: str) -> None:
         out = subprocess.run(
             ["python -m pytest tests/"], shell=True, check=True, capture_output=True
         )
-        assert "FAILED" not in str(out)
+        assert "FAILED" not in str(out), str(out)
     if os.path.isdir("dist") is True:
         subprocess.run(["rm -r dist "], shell=True, check=True)
     if os.path.isdir("build") is True:
